pub enum DependencyCondition {
IfTargetActive,
IfBudgetAbove(StrategyId),
IfEngineMode(EngineMode),
}Expand description
A condition that must be met for a dependency to be active.
Variants
IfTargetActive
Only depends on the target if the target is active this frame.
IfBudgetAbove(StrategyId)
Only depends on the target if the current budget >= this strategy.
IfEngineMode(EngineMode)
Only depends on the target in this engine mode.