pub enum DependencyKind {
Hard,
Soft,
Parallel,
}Expand description
The type of dependency constraint.
Variants
Hard
Must execute BEFORE this agent. If target is skipped, this agent is also skipped.
Soft
Prefers to execute after the target, but can execute without it.
Parallel
Can execute in parallel (same phase). No ordering constraint.