pub trait AsAny { // Required method fn as_any(&self) -> &dyn Any; }
Helper trait to allow downcasting dyn Material trait objects to their concrete types.
dyn Material
Returns a reference to the inner value as &dyn Any.
&dyn Any