AudioStream

Trait AudioStream 

pub trait AudioStream: Send + Sync {
    // Required method
    fn stream_info(&self) -> StreamInfo;
}
Live audio stream handle. Drop = stop.

Required Methods

fn stream_info(&self) -> StreamInfo

Channel count and sample rate of the stream as actually opened by the backend (may differ from the bus’s nominal info if the hardware imposed a different format).

Implementors