pub struct RigidBodyHandle(pub u64);Expand description
Opaque handle to a rigid body in the physics engine.
Tuple Fields
0: u64Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for RigidBodyHandle
impl<'__de, __Context> BorrowDecode<'__de, __Context> for RigidBodyHandle
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for RigidBodyHandle
impl Clone for RigidBodyHandle
Sourcefn clone(&self) -> RigidBodyHandle
fn clone(&self) -> RigidBodyHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RigidBodyHandle
impl Debug for RigidBodyHandle
Sourceimpl<__Context> Decode<__Context> for RigidBodyHandle
impl<__Context> Decode<__Context> for RigidBodyHandle
Sourceimpl<'de> Deserialize<'de> for RigidBodyHandle
impl<'de> Deserialize<'de> for RigidBodyHandle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for RigidBodyHandle
impl Encode for RigidBodyHandle
Sourceimpl Hash for RigidBodyHandle
impl Hash for RigidBodyHandle
Sourceimpl PartialEq for RigidBodyHandle
impl PartialEq for RigidBodyHandle
Sourcefn eq(&self, other: &RigidBodyHandle) -> bool
fn eq(&self, other: &RigidBodyHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RigidBodyHandle
impl Serialize for RigidBodyHandle
impl Copy for RigidBodyHandle
impl Eq for RigidBodyHandle
impl StructuralPartialEq for RigidBodyHandle