pub struct ComputePipelineId(pub u64);Expand description
An opaque handle to a compiled compute pipeline state object.
This ID is returned by [GraphicsDevice::create_compute_pipeline] and is used
to reference the pipeline when recording compute dispatches.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ComputePipelineId
impl Clone for ComputePipelineId
Sourcefn clone(&self) -> ComputePipelineId
fn clone(&self) -> ComputePipelineId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputePipelineId
impl Debug for ComputePipelineId
Sourceimpl Hash for ComputePipelineId
impl Hash for ComputePipelineId
Sourceimpl Ord for ComputePipelineId
impl Ord for ComputePipelineId
Sourcefn cmp(&self, other: &ComputePipelineId) -> Ordering
fn cmp(&self, other: &ComputePipelineId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ComputePipelineId
impl PartialEq for ComputePipelineId
Sourcefn eq(&self, other: &ComputePipelineId) -> bool
fn eq(&self, other: &ComputePipelineId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ComputePipelineId
impl PartialOrd for ComputePipelineId
impl Copy for ComputePipelineId
impl Eq for ComputePipelineId
impl StructuralPartialEq for ComputePipelineId