pub struct Operations<V> {
pub load: LoadOp<V>,
pub store: StoreOp,
}Expand description
Defines the load and store operations for a single render pass attachment.
Fields
load: LoadOp<V>The operation to perform at the beginning of the pass.
store: StoreOpThe operation to perform at the end of the pass.