TextureUsage

Struct TextureUsage 

pub struct TextureUsage { /* private fields */ }
A set of flags describing the allowed usages of a TextureId.

Implementations

Source

impl TextureUsage

pub const EMPTY: Self

An empty set of flags.

pub const COPY_SRC: Self

The texture can be used as the source of a copy operation.

pub const COPY_DST: Self

The texture can be used as the destination of a copy operation.

pub const TEXTURE_BINDING: Self

The texture can be bound in a shader for sampling (reading).

pub const STORAGE_BINDING: Self

The texture can be used as a storage texture (read/write access from shaders).

pub const RENDER_ATTACHMENT: Self

The texture can be used as a color or multisample resolve attachment in a render pass.

pub const DEPTH_STENCIL_ATTACHMENT: Self

The texture can be used as a depth/stencil target (for render attachments).

pub const fn from_bits_truncate(bits: u32) -> Self

Creates a new bitflag set from the given raw bits. Bits not corresponding to any defined flag are kept.

pub const fn bits(&self) -> u32

Returns the raw value of the bitflag set.

pub const fn contains(&self, other: Self) -> bool

Returns true if all flags in other are contained within self.

pub const fn intersects(&self, other: Self) -> bool

Returns true if any flag in other is contained within self.

pub fn insert(&mut self, other: Self)

Inserts the flags in other into self.

pub fn remove(&mut self, other: Self)

Removes the flags in other from self.

pub fn toggle(&mut self, other: Self)

Toggles the flags in other in self.

pub const fn with(self, other: Self) -> Self

Returns a new Self with other flags inserted.

pub const fn without(self, other: Self) -> Self

Returns a new Self with other flags removed.