pub struct TabGroupLayout {
pub rect: DockRect,
pub panels: Vec<String>,
pub active: usize,
}Expand description
One tab group placed on screen.
Fields
rect: DockRectArea assigned to the whole group, tab strip included.
panels: Vec<String>Panel ids in tab order.
active: usizeIndex of the visible panel.
Implementations
Sourceimpl TabGroupLayout
impl TabGroupLayout
Sourcepub fn active_panel(&self) -> Option<&str>
pub fn active_panel(&self) -> Option<&str>
Id of the panel whose content should be drawn.