Icon

Enum Icon 

pub enum Icon {
Show 66 variants Search, ChevronDown, ChevronRight, ArrowRight, Cube, Light, Camera, Folder, Layers, Globe, Axes, Grid, Sparkles, Package, Play, Pause, Stop, StepForward, Eye, EyeOff, Lock, Plus, More, Filter, Trash, Bell, Settings, Share, Hammer, Branch, Menu, Tag, Move, Rotate, Scale, Hand, Crosshair, Database, Film, Terminal, Code, Image, Music, Pen, Info, Warn, Error, Zap, Command, Wifi, Cpu, Memory, Check, Close, FolderOpen, Save, Copy, Pencil, Download, Refresh, Github, ArrowLeft, Box, Dot, Circle, CheckCircle,
}
A semantic icon identifier mapped to a Lucide codepoint.

Variants



Search



ChevronDown



ChevronRight



ArrowRight



Cube



Light



Camera



Folder



Layers



Globe



Axes



Grid



Sparkles



Package



Play



Pause



Stop



StepForward



Eye



EyeOff



Lock



Plus



More



Filter



Trash



Bell



Settings



Share



Hammer



Branch



Menu



Tag



Move



Rotate



Scale



Hand



Crosshair



Database



Film



Terminal



Code



Image



Music



Pen



Info



Warn



Error



Zap



Command



Wifi



Cpu



Memory



Check



Close



FolderOpen



Save



Copy



Pencil



Download



Refresh



Github



ArrowLeft



Box



Dot



Circle



CheckCircle

Implementations

Source

impl Icon

pub fn glyph(self) -> &'static str

Returns the Lucide PUA glyph for this icon as a &'static str. Use it with paint_text_styled(.., FontFamilyHint::Icons, ..) or with any widget that renders icon text.