pub struct CornerRadius {
pub nw: f32,
pub ne: f32,
pub sw: f32,
pub se: f32,
}Expand description
Per-corner radius of a rounded rectangle, in logical pixels.
Backends that only support a single radius use the maximum of the
four corners (or nw if they’re all expected equal).
Fields
nw: f32North-west (top-left).
ne: f32North-east (top-right).
sw: f32South-west (bottom-left).
se: f32South-east (bottom-right).
Implementations