LaneKind

Enum LaneKind 

pub enum LaneKind {
    Render,
    Shadow,
    Physics,
    Audio,
    Asset,
    Scene,
    Ecs,
}
Classification of lane types, used for routing and filtering.

Agents use this to identify compatible lanes during GORNA negotiation and lane selection.

Variants



Render

Main scene rendering (forward, deferred, etc.)



Shadow

Shadow map generation



Physics

Physics simulation



Audio

Audio mixing and spatialization



Asset

Asset loading and processing



Scene

Scene serialization/deserialization



Ecs

ECS maintenance (compaction, garbage collection)