pub struct DynamicTree<T: Clone> { /* private fields */ }Expand description
A dynamic AABB tree for efficient spatial queries.
Implementations
Sourceimpl<T: Clone> DynamicTree<T>
impl<T: Clone> DynamicTree<T>
Sourcepub fn insert(&mut self, aabb: Aabb, user_data: T) -> i32
pub fn insert(&mut self, aabb: Aabb, user_data: T) -> i32
Inserts a new leaf into the tree and returns its index.
Sourcepub fn update(
&mut self,
leaf: i32,
aabb: Aabb,
displacement: Vec3,
force_update: bool,
) -> bool
pub fn update( &mut self, leaf: i32, aabb: Aabb, displacement: Vec3, force_update: bool, ) -> bool
Updates a leaf with a new AABB. If the new AABB is still within the “fat” AABB, no tree update is needed.
Sourcepub fn get_user_data(&self, leaf: i32) -> &T
pub fn get_user_data(&self, leaf: i32) -> &T
Returns the user data for a given leaf.
Sourcepub fn query_pairs<F>(&self, callback: F)
pub fn query_pairs<F>(&self, callback: F)
Queries the tree for all pairs of overlapping leaves.