pub enum VertexStepMode {
Vertex,
Instance,
}Expand description
Defines how often the GPU advances to the next element in a vertex buffer.
Variants
Vertex
The GPU advances to the next element for each vertex.
Instance
The GPU advances to the next element only for each new instance being rendered.