pub struct TextureUsage { /* private fields */ }Expand description
A set of flags describing the allowed usages of a TextureId.
Implementations
Sourceimpl TextureUsage
impl TextureUsage
Sourcepub const TEXTURE_BINDING: Self
pub const TEXTURE_BINDING: Self
The texture can be bound in a shader for sampling (reading).
Sourcepub const STORAGE_BINDING: Self
pub const STORAGE_BINDING: Self
The texture can be used as a storage texture (read/write access from shaders).
Sourcepub const RENDER_ATTACHMENT: Self
pub const RENDER_ATTACHMENT: Self
The texture can be used as a color or multisample resolve attachment in a render pass.
Sourcepub const DEPTH_STENCIL_ATTACHMENT: Self
pub const DEPTH_STENCIL_ATTACHMENT: Self
The texture can be used as a depth/stencil target (for render attachments).
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Creates a new bitflag set from the given raw bits. Bits not corresponding to any defined flag are kept.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all flags in other are contained within self.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if any flag in other is contained within self.