pub struct AnyMap { /* private fields */ }Expand description
A thread-safe type-erased map — one value per type.
Implementations
Sourceimpl AnyMap
impl AnyMap
Sourcepub fn insert<T: Send + Sync + 'static>(&mut self, value: T)
pub fn insert<T: Send + Sync + 'static>(&mut self, value: T)
Inserts a value, replacing any existing value of the same type.
Sourcepub fn get<T: Send + Sync + 'static>(&self) -> Option<Arc<T>>
pub fn get<T: Send + Sync + 'static>(&self) -> Option<Arc<T>>
Returns a cloned Arc reference to the value of the given type, if present.